@@ -1,44 +1,46 @@
-/*-------------------------------------------------------------------------------------*/
-/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search - version 3.8.0      */
-/*                                                                                     */
-/*                                                                                     */
-/*  NOMAD - version 3.8.0 has been created by                                          */
-/*                 Charles Audet        - Ecole Polytechnique de Montreal              */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  The copyright of NOMAD - version 3.8.0 is owned by                                 */
-/*                 Sebastien Le Digabel - Ecole Polytechnique de Montreal              */
-/*                 Christophe Tribes    - Ecole Polytechnique de Montreal              */
-/*                                                                                     */
-/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                                 */
-/*                                                                                     */
-/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created and     */
-/*  developed by Mark Abramson, Charles Audet, Gilles Couture and John E. Dennis Jr.,  */
-/*  and were funded by AFOSR and Exxon Mobil.                                          */
-/*                                                                                     */
-/*                                                                                     */
-/*  Contact information:                                                               */
-/*    Ecole Polytechnique de Montreal - GERAD                                          */
-/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada                  */
-/*    e-mail: nomad@gerad.ca                                                           */
-/*    phone : 1-514-340-6053 #6928                                                     */
-/*    fax   : 1-514-340-5665                                                           */
-/*                                                                                     */
-/*  This program is free software: you can redistribute it and/or modify it under the  */
-/*  terms of the GNU Lesser General Public License as published by the Free Software   */
-/*  Foundation, either version 3 of the License, or (at your option) any later         */
-/*  version.                                                                           */
-/*                                                                                     */
-/*  This program is distributed in the hope that it will be useful, but WITHOUT ANY    */
-/*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A    */
-/*  PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more details.   */
-/*                                                                                     */
-/*  You should have received a copy of the GNU Lesser General Public License along     */
-/*  with this program. If not, see <http://www.gnu.org/licenses/>.                     */
-/*                                                                                     */
-/*  You can find information on the NOMAD software at www.gerad.ca/nomad               */
-/*-------------------------------------------------------------------------------------*/
+/*---------------------------------------------------------------------------------*/
+/*  NOMAD - Nonlinear Optimization by Mesh Adaptive Direct search -                */
+/*                                                                                 */
+/*  NOMAD - version 3.9.1 has been created by                                      */
+/*                 Charles Audet               - Ecole Polytechnique de Montreal   */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  The copyright of NOMAD - version 3.9.1 is owned by                             */
+/*                 Sebastien Le Digabel        - Ecole Polytechnique de Montreal   */
+/*                 Viviane Rochon Montplaisir - Ecole Polytechnique de Montreal   */
+/*                 Christophe Tribes           - Ecole Polytechnique de Montreal   */
+/*                                                                                 */
+/*  NOMAD v3 has been funded by AFOSR and Exxon Mobil.                             */
+/*                                                                                 */
+/*  NOMAD v3 is a new version of NOMAD v1 and v2. NOMAD v1 and v2 were created     */
+/*  and developed by Mark Abramson, Charles Audet, Gilles Couture, and John E.     */
+/*  Dennis Jr., and were funded by AFOSR and Exxon Mobil.                          */
+/*                                                                                 */
+/*  Contact information:                                                           */
+/*    Ecole Polytechnique de Montreal - GERAD                                      */
+/*    C.P. 6079, Succ. Centre-ville, Montreal (Quebec) H3C 3A7 Canada              */
+/*    e-mail: nomad@gerad.ca                                                       */
+/*    phone : 1-514-340-6053 #6928                                                 */
+/*    fax   : 1-514-340-5665                                                       */
+/*                                                                                 */
+/*  This program is free software: you can redistribute it and/or modify it        */
+/*  under the terms of the GNU Lesser General Public License as published by       */
+/*  the Free Software Foundation, either version 3 of the License, or (at your     */
+/*  option) any later version.                                                     */
+/*                                                                                 */
+/*  This program is distributed in the hope that it will be useful, but WITHOUT    */
+/*  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or          */
+/*  FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License    */
+/*  for more details.                                                              */
+/*                                                                                 */
+/*  You should have received a copy of the GNU Lesser General Public License       */
+/*  along with this program. If not, see <http://www.gnu.org/licenses/>.           */
+/*                                                                                 */
+/*  You can find information on the NOMAD software at www.gerad.ca/nomad           */
+/*---------------------------------------------------------------------------------*/
+
 /**
  \file   Stats.cpp
  \brief  Algorithm stats (implementation)
@@ -57,7 +59,7 @@ NOMAD::Stats & NOMAD::Stats::operator = ( const NOMAD::Stats & s )
     _sim_bb_eval       = s._sim_bb_eval;
     _sgte_eval         = s._sgte_eval;
     _bb_eval           = s._bb_eval;
-    _block_eval         = s._block_eval;
+    _block_eval        = s._block_eval;
     _failed_eval       = s._failed_eval;
     _cache_hits        = s._cache_hits;
     _interrupted_eval  = s._interrupted_eval;
@@ -77,6 +79,17 @@ NOMAD::Stats & NOMAD::Stats::operator = ( const NOMAD::Stats & s )
     _nb_LH_searches    = s._nb_LH_searches;
     LH_LH_pts            = s.LH_LH_pts;
     LH_LH_success        = s.LH_LH_success;
+    _nb_NM_searches    = s._nb_NM_searches;
+    NM_NM_pts            = s.NM_NM_pts;
+    NM_NM_success        = s.NM_NM_success;
+    NM_NM_step           = s.NM_NM_step;
+    NM_NM_initial_step   = s.NM_NM_initial_step;
+    NM_NM_expand_step    = s.NM_NM_expand_step;
+    NM_NM_reflect_step   = s.NM_NM_reflect_step;
+    NM_NM_inside_contraction_step  = s.NM_NM_inside_contraction_step;
+    NM_NM_outside_contraction_step = s.NM_NM_outside_contraction_step;
+    NM_NM_shrink_step    = s.NM_NM_shrink_step;
+    NM_NM_bb_eval        = s.NM_NM_bb_eval;
     _nb_cache_searches = s._nb_cache_searches;
     CS_CS_pts            = s.CS_CS_pts;
     CS_CS_success        = s.CS_CS_success;
@@ -110,11 +123,11 @@ NOMAD::Stats & NOMAD::Stats::operator = ( const NOMAD::Stats & s )
 /*---------------------------------------------------------*/
 void NOMAD::Stats::reset ( void )
 {
-    _eval                =
+    _eval              =
     _sim_bb_eval       =
     _sgte_eval         =
     _bb_eval           =
-    _block_eval         =
+    _block_eval        =
     _failed_eval       =
     _cache_hits        =
     _interrupted_eval  =
@@ -133,6 +146,21 @@ void NOMAD::Stats::reset ( void )
     _nb_LH_searches    =
     LH_LH_pts            =
     LH_LH_success        =
+    _nb_NM_searches    =
+    NM_NM_pts            =
+    NM_NM_success        =
+    NM_NM_step           =
+    NM_NM_initial_step   =
+    NM_NM_expand_step    =
+    NM_NM_inside_contraction_step  =
+    NM_NM_reflect_step   =
+    NM_NM_outside_contraction_step =
+    NM_NM_shrink_step    =
+    NM_NM_bb_eval        =
+    _nb_TM_searches    =
+    TM_TM_pts            =
+    TM_TM_success        =
+    TM_TM_bb_eval        =
     _nb_cache_searches =
     CS_CS_pts            =
     CS_CS_success        =
@@ -187,6 +215,21 @@ void NOMAD::Stats::update ( const NOMAD::Stats & s , bool for_search )
     _nb_LH_searches    += s._nb_LH_searches;
     LH_LH_pts            += s.LH_LH_pts;
     LH_LH_success        += s.LH_LH_success;
+    _nb_NM_searches    += s._nb_NM_searches;
+    NM_NM_pts            += s.NM_NM_pts;
+    NM_NM_success        += s.NM_NM_success;
+    NM_NM_step           += s.NM_NM_step;
+    NM_NM_initial_step   += s.NM_NM_initial_step;
+    NM_NM_expand_step    += s.NM_NM_expand_step;
+    NM_NM_reflect_step   += s.NM_NM_reflect_step;
+    NM_NM_inside_contraction_step  += s.NM_NM_inside_contraction_step;
+    NM_NM_outside_contraction_step += s.NM_NM_outside_contraction_step;
+    NM_NM_shrink_step    += s.NM_NM_shrink_step;
+    NM_NM_bb_eval        += s.NM_NM_bb_eval;
+    _nb_TM_searches    += s._nb_TM_searches;
+    TM_TM_pts            += s.TM_TM_pts;
+    TM_TM_success        += s.TM_TM_success;
+    TM_TM_bb_eval        += s.TM_TM_bb_eval;
     _nb_cache_searches += s._nb_cache_searches;
     CS_CS_pts            += s.CS_CS_pts;
     CS_CS_success        += s.CS_CS_success;
@@ -314,6 +357,25 @@ void NOMAD::Stats::display ( const NOMAD::Display & out ) const
     if ( _nb_LH_searches > 0 )
         out << "LH search successes             : " << LH_LH_success          << std::endl
         << "LH search points                : " << LH_LH_pts              << std::endl;
+    out << "number of NM searches           : "   << _nb_NM_searches      << std::endl;
+    if ( _nb_NM_searches > 0 )
+        out << "NM search successes             : " << NM_NM_success          << std::endl
+        << "NM search points                : " << NM_NM_pts << std::endl
+        << "NM blackbox evaluations         : " << NM_NM_bb_eval         << std::endl
+        << "NM search steps                 : " << NM_NM_step
+        << " ( initial: " << NM_NM_initial_step
+        << ", expands: " << NM_NM_expand_step
+        << ", reflects: " << NM_NM_reflect_step
+        << ", inside contractions: " << NM_NM_inside_contraction_step
+        << ", outside contractions: " << NM_NM_outside_contraction_step
+        << ", shrinks: " << NM_NM_shrink_step << " )" << std::endl
+        << "NM search successes             : " << NM_NM_success << std::endl;
+    
+    out << "number of TM line searches      : "   << _nb_TM_searches      << std::endl;
+    if ( _nb_TM_searches > 0 )
+        out << "TM line search successes        : " << TM_TM_success          << std::endl
+        << "TM line search points           : " << TM_TM_pts << std::endl
+        << "TM blackbox evaluations         : " << TM_TM_bb_eval         << std::endl;
     out << "number of cache searches        : "   << _nb_cache_searches   << std::endl;
     if ( _nb_cache_searches > 0 )
         out << "cache search successes          : " << CS_CS_success          << std::endl
@@ -360,7 +422,7 @@ void NOMAD::Stats::display ( const NOMAD::Display & out ) const
     if ( MPI_MPI_data_size < 0 )
         out << "-";
     else
-        out.display_size_of ( MPI_MPI_data_size );
+        out.display_size_of ( static_cast<float>(MPI_MPI_data_size) );
     out << std::endl;
 #endif
     
