@@ -1,6 +1,6 @@
 /*-------------------------------------------------------------------------------------*/
 /*  sgtelib - A surrogate model library for derivative-free optimization               */
-/*  Version 2.0.1                                                                      */
+/*  Version 2.0.2                                                                      */
 /*                                                                                     */
 /*  Copyright (C) 2012-2017  Sebastien Le Digabel - Ecole Polytechnique, Montreal      */
 /*                           Bastien Talgorn - McGill University, Montreal             */
@@ -26,6 +26,11 @@
 #include "Surrogate_Utils.hpp"
 
 #include "RNG.hpp"   //zhenghua for rand.
+
+#include <string>
+#include <sstream>
+
+
 /*-------------------------------*/
 /*     string comparison         */
 /*-------------------------------*/
@@ -115,7 +120,7 @@ void SGTELIB::append_file (const std::string & s , const std::string & file){
     dummy_str = system( cmd.c_str() );
   }
   cmd = "echo "+s+" >> "+file;
-  //SGTELIB::rout << "cmd : " << cmd << "\n";
+  //std::cout << "cmd : " << cmd << "\n";
   dummy_str = system( cmd.c_str() );
 }//
 
@@ -138,8 +143,8 @@ void SGTELIB::wait (double t) {
 /*  isdef (not nan nor inf)     */
 /*-------------------------------*/
 bool SGTELIB::isdef ( const double x ) {
-  if ( crs_isnan(x) ) return false;
-  if ( crs_isinf(x) ) return false;
+  if ( crs_isnan(x) ) return false;   //zhenghua
+  if ( crs_isinf(x) ) return false;   //zhenghua
   if ( fabs(x)>=SGTELIB::INF) return false;
   if ( fabs(x)>=1e+16){
     return false;
@@ -156,8 +161,10 @@ double SGTELIB::dist ( const double * x , const double * y , int n ) {
   double s = 0.0;
   double d = 0;
   for ( int i = 0 ; i < n ; ++i )
+  {
     d = x[i]-y[i];
     s += d*d;
+  }
   return sqrt(s);
 }
 
@@ -325,86 +332,6 @@ std::string SGTELIB::weight_type_to_str ( const SGTELIB::weight_t cb ) {
   }
 }//
 
-/*----------------------------------------------------------*/
-std::string SGTELIB::metric_type_to_str ( const SGTELIB::metric_t mt ) {
-/*----------------------------------------------------------*/
-  switch (mt){
-    case SGTELIB::METRIC_EMAX   : return "EMAX"   ;
-    case SGTELIB::METRIC_EMAXCV : return "EMAXCV" ;
-    case SGTELIB::METRIC_RMSE   : return "RMSE"   ;
-    case SGTELIB::METRIC_RMSECV : return "RMSECV" ;
-    case SGTELIB::METRIC_ARMSE  : return "ARMSE"  ;
-    case SGTELIB::METRIC_ARMSECV: return "ARMSECV";
-    case SGTELIB::METRIC_OE     : return "OE"     ; 
-    case SGTELIB::METRIC_OECV   : return "OECV"   ; 
-    case SGTELIB::METRIC_AOE    : return "AOE"    ;
-    case SGTELIB::METRIC_AOECV  : return "AOECV"  ;
-    case SGTELIB::METRIC_EFIOE  : return "EFIOE"    ;
-    case SGTELIB::METRIC_EFIOECV: return "EFIOECV"  ;
-    case SGTELIB::METRIC_LINV   : return "LINV"   ;
-    default:
-      throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Undefined metric" );
-  }
-}//
-
-
-/*----------------------------------------------------------*/
-bool SGTELIB::metric_multiple_obj ( const SGTELIB::metric_t mt ) {
-/*----------------------------------------------------------*/
-  switch (mt){
-    case SGTELIB::METRIC_EMAX   : 
-    case SGTELIB::METRIC_EMAXCV : 
-    case SGTELIB::METRIC_RMSE   : 
-    case SGTELIB::METRIC_RMSECV : 
-    case SGTELIB::METRIC_OE     : 
-    case SGTELIB::METRIC_OECV   : 
-    case SGTELIB::METRIC_LINV   : 
-      return true;
-    case SGTELIB::METRIC_ARMSE  : 
-    case SGTELIB::METRIC_ARMSECV: 
-    case SGTELIB::METRIC_AOE    : 
-    case SGTELIB::METRIC_AOECV  : 
-    case SGTELIB::METRIC_EFIOE    : 
-    case SGTELIB::METRIC_EFIOECV  : 
-      return false;
-    default:
-      throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Undefined metric" );
-  }
-}//
-
-/*----------------------------------------------------------*/
-SGTELIB::metric_t SGTELIB::metric_convert_single_obj ( const SGTELIB::metric_t mt ) {
-/*----------------------------------------------------------*/
-  switch (mt){
-    // Metric that do not have a "Single obj" equivalent
-    case SGTELIB::METRIC_EMAX   : 
-    case SGTELIB::METRIC_EMAXCV : 
-    case SGTELIB::METRIC_LINV   : 
-      SGTELIB::rout << "The metric " << SGTELIB::metric_type_to_str(mt) << "is not supported for this type of model\n";
-      SGTELIB::rout << "AOECV metric will be used.\n";
-      return SGTELIB::METRIC_AOECV;
-    // Metric that have a "single obj" equivalent
-    case SGTELIB::METRIC_RMSE   : 
-      return SGTELIB::METRIC_ARMSE;
-    case SGTELIB::METRIC_RMSECV : 
-      return SGTELIB::METRIC_ARMSECV;
-    case SGTELIB::METRIC_OE     : 
-      return SGTELIB::METRIC_AOE;
-    case SGTELIB::METRIC_OECV   : 
-      return SGTELIB::METRIC_AOECV;
-    // Metric that are "single obj"
-    case SGTELIB::METRIC_ARMSE  : 
-    case SGTELIB::METRIC_ARMSECV: 
-    case SGTELIB::METRIC_AOE    : 
-    case SGTELIB::METRIC_AOECV  : 
-    case SGTELIB::METRIC_EFIOE    : 
-    case SGTELIB::METRIC_EFIOECV  : 
-      return mt;
-    default:
-      throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Undefined metric" );
-  }
-}//
-
 
 
 /*----------------------------------------------------------*/
@@ -489,26 +416,6 @@ SGTELIB::distance_t SGTELIB::int_to_distance_type ( const int i ) {
   }
 }//
 
-/*----------------------------------------------------------*/
-SGTELIB::metric_t SGTELIB::str_to_metric_type ( const std::string & s ) {
-/*----------------------------------------------------------*/
-  std::string ss = SGTELIB::toupper(s);
-  if ( ss=="EMAX"   ){ return SGTELIB::METRIC_EMAX    ;}
-  if ( ss=="EMAXCV" ){ return SGTELIB::METRIC_EMAXCV  ;}
-  if ( ss=="RMSE"   ){ return SGTELIB::METRIC_RMSE    ;}
-  if ( ss=="RMSECV" ){ return SGTELIB::METRIC_RMSECV  ;}
-  if ( ss=="PRESS"  ){ return SGTELIB::METRIC_RMSECV  ;}
-  if ( ss=="ARMSE"  ){ return SGTELIB::METRIC_ARMSE   ;}
-  if ( ss=="ARMSECV"){ return SGTELIB::METRIC_ARMSECV ;}
-  if ( ss=="OE"     ){ return SGTELIB::METRIC_OE      ;}
-  if ( ss=="OECV"   ){ return SGTELIB::METRIC_OECV    ;}
-  if ( ss=="AOE"    ){ return SGTELIB::METRIC_AOE     ;}
-  if ( ss=="AOECV"  ){ return SGTELIB::METRIC_AOECV   ;}
-  if ( ss=="EFIOE"    ){ return SGTELIB::METRIC_EFIOE ;}
-  if ( ss=="EFIOECV"  ){ return SGTELIB::METRIC_EFIOECV;}
-  if ( ss=="LINV"   ){ return SGTELIB::METRIC_LINV    ;}
-  throw SGTELIB::Exception ( __FILE__ , __LINE__ ,"Unrecognised string \""+s+"\" ( "+ss+" )" );
-}//
 
 
 
@@ -641,7 +548,7 @@ double SGTELIB::gammacdfinv(double f, double a, double b){
   if (f==1.0) return INF;
   if (f==0.0) return 0;
 
-  //SGTELIB::rout << "f,a,b : " << f << " " << a << " " << b << "\n";
+  //std::cout << "f,a,b : " << f << " " << a << " " << b << "\n";
 
   double xmin = 0;
   double xmax = 1;
@@ -651,7 +558,7 @@ int k = 0;
   while (SGTELIB::gammacdf(xmax,a,b)<f){
     xmin = xmax;
     xmax*=2.0;
-    //SGTELIB::rout << "up " << xmax << " " << a << " " << b << " " <<  SGTELIB::gammacdf(xmax,a,b) << "\n";
+    //std::cout << "up " << xmax << " " << a << " " << b << " " <<  SGTELIB::gammacdf(xmax,a,b) << "\n";
     k++;
     if (k>10) break;
   }
@@ -660,7 +567,7 @@ int k = 0;
     xtry = (xmin+xmax)/2.0;
     if (SGTELIB::gammacdf(xtry,a,b)>f) xmax = xtry;
     else xmin = xtry;
-    //SGTELIB::rout << "dichotomie : " << xtry << "\n";
+    //std::cout << "dichotomie : " << xtry << "\n";
   }
   return (xmin+xmax)/2.0;
 }//
@@ -704,7 +611,7 @@ int SGTELIB::diff_ms(timeval t1, timeval t2){
 /*  uniform rand generator               */
 /*----------------------------------------*/
 double SGTELIB::uniform_rand (void){
-  return double(NOMAD::RNG::rand() / double(UINT32_MAX));
+  return double(NOMAD::RNG::rand() / double(UINT32_MAX));   //zhenghua
 }//
 
 /*----------------------------------------*/
